package com.ruoyi.ss.customerService.mapper;

import java.util.List;
import com.ruoyi.ss.customerService.domain.CustomerService;
import com.ruoyi.ss.customerService.domain.CustomerServiceVO;
import com.ruoyi.ss.customerService.domain.CustomerServiceQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 客服Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-19
 */
public interface CustomerServiceMapper
{
    /**
     * 查询客服
     *
     * @param id 客服主键
     * @return 客服
     */
    public CustomerServiceVO selectCustomerServiceById(Long id);

    /**
     * 查询客服列表
     *
     * @param query 客服
     * @return 客服集合
     */
    public List<CustomerServiceVO> selectCustomerServiceList(@Param("query")CustomerServiceQuery query);

    /**
     * 新增客服
     *
     * @param customerService 客服
     * @return 结果
     */
    public int insertCustomerService(CustomerService customerService);

    /**
     * 修改客服
     *
     * @param customerService 客服
     * @return 结果
     */
    public int updateCustomerService(@Param("data") CustomerService customerService);

    /**
     * 删除客服
     *
     * @param id 客服主键
     * @return 结果
     */
    public int deleteCustomerServiceById(Long id);

    /**
     * 批量删除客服
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCustomerServiceByIds(Long[] ids);
}
